"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createWcp = void 0;
var _wcp = require("@webiny/wcp");
var _error = _interopRequireDefault(require("@webiny/error"));
var _utils = require("./utils");
const wcpProjectEnvironment = (0, _wcp.getWcpProjectEnvironment)();
const cachedWcpProjectLicense = {
  cacheKey: null,
  project: null,
  license: new _wcp.NullLicense()
};
const createWcp = async (params = {}) => {
  if (params.testProjectLicense) {
    cachedWcpProjectLicense.license = _wcp.License.fromLicenseDto(params.testProjectLicense);
  } else if (wcpProjectEnvironment) {
    const currentCacheKey = (0, _utils.getWcpProjectLicenseCacheKey)();
    if (cachedWcpProjectLicense.cacheKey !== currentCacheKey) {
      cachedWcpProjectLicense.cacheKey = currentCacheKey;
      // Pull the project license from the WCP API.
      const decryptedLicenseDto = await (0, _wcp.getWcpProjectLicense)({
        orgId: wcpProjectEnvironment.org.id,
        projectId: wcpProjectEnvironment.project.id,
        projectEnvironmentApiKey: wcpProjectEnvironment.apiKey
      });
      if (decryptedLicenseDto) {
        cachedWcpProjectLicense.project = {
          orgId: decryptedLicenseDto.orgId,
          projectId: decryptedLicenseDto.projectId,
          package: decryptedLicenseDto.package
        };
      }
      cachedWcpProjectLicense.license = _wcp.License.fromLicenseDto(decryptedLicenseDto);
    }
  } else if (process.env.WCP_PROJECT_LICENSE) {}

  // Returns the dedicated Webiny Control Panel (WCP) REST API URL for given org and project.
  const getWcpProjectUrl = (path = "") => {
    if (!wcpProjectEnvironment) {
      return null;
    }
    const orgId = wcpProjectEnvironment.org.id;
    const projectId = wcpProjectEnvironment.project.id;
    const url = ["/orgs", orgId, "projects", projectId, path].filter(Boolean).join("/");
    return (0, _wcp.getWcpApiUrl)(url);
  };
  const updateSeats = async operation => {
    if (!wcpProjectEnvironment) {
      return;
    }
    const updateSeatsUrl = getWcpProjectUrl("package/seats");
    const response = await (0, _utils.wcpFetch)({
      url: updateSeatsUrl,
      authorization: wcpProjectEnvironment.apiKey,
      body: {
        operation
      },
      meta: {
        action: operation + "Seats"
      }
    });
    if (response.error) {
      const message = response.message || `Failed to ${operation} user seats.`;
      console.error(message, response.status, response.statusText);
      throw new _error.default(message, "WCP_CANNOT_UPDATE_USER_TENANTS");
    }
  };
  const updateTenants = async operation => {
    if (!wcpProjectEnvironment) {
      return;
    }
    const updateTenantsUrl = getWcpProjectUrl("package/tenants");
    const response = await (0, _utils.wcpFetch)({
      url: updateTenantsUrl,
      authorization: wcpProjectEnvironment.apiKey,
      body: {
        operation
      },
      meta: {
        action: operation + "Tenants"
      }
    });
    if (response.error) {
      const message = response.message || `Failed to ${operation} tenants.`;
      console.error(message, response.status, response.statusText);
      throw new _error.default(message, "WCP_CANNOT_UPDATE_USER_TENANTS");
    }
  };
  return {
    getRawLicense: () => {
      return cachedWcpProjectLicense.license.getRawLicense();
    },
    getProject: () => {
      return cachedWcpProjectLicense.project;
    },
    getProjectEnvironment: () => {
      return wcpProjectEnvironment;
    },
    getProjectLicense: () => {
      return cachedWcpProjectLicense.license;
    },
    canUseFeature(wcpFeatureId) {
      return cachedWcpProjectLicense.license.canUseFeature(wcpFeatureId);
    },
    canUseAacl() {
      return cachedWcpProjectLicense.license.canUseAacl();
    },
    canUseTeams() {
      return cachedWcpProjectLicense.license.canUseTeams();
    },
    canUseFolderLevelPermissions() {
      return cachedWcpProjectLicense.license.canUseFolderLevelPermissions();
    },
    canUsePrivateFiles() {
      return cachedWcpProjectLicense.license.canUsePrivateFiles();
    },
    canUseAuditLogs() {
      return cachedWcpProjectLicense.license.canUseAuditLogs();
    },
    canUseRecordLocking() {
      return cachedWcpProjectLicense.license.canUseRecordLocking();
    },
    canUseFileManagerThreatDetection() {
      return cachedWcpProjectLicense.license.canUseFileManagerThreatDetection();
    },
    ensureCanUseFeature(wcpFeatureId) {
      if (cachedWcpProjectLicense.license.canUseFeature(wcpFeatureId)) {
        return;
      }
      let message = `The ${wcpFeatureId} Webiny Control Panel feature cannot be used because your project license does not permit it.`;
      if (wcpProjectEnvironment) {
        const {
          org,
          project
        } = wcpProjectEnvironment;
        const upgradeProjectLicenseLink = (0, _wcp.getWcpAppUrl)(`/${org.id}/${project.id}/settings`);
        message += `To upgrade your project license, please use the following link: ${upgradeProjectLicenseLink}.`;
      }
      throw new _error.default(message, "WCP_CANNOT_USE_FEATURE", {
        wcpFeatureId
      });
    },
    async incrementSeats() {
      await updateSeats("increment");
    },
    async decrementSeats() {
      await updateSeats("decrement");
    },
    async incrementTenants() {
      await updateTenants("increment");
    },
    async decrementTenants() {
      await updateTenants("decrement");
    }
  };
};
exports.createWcp = createWcp;

//# sourceMappingURL=createWcp.js.map